@@ -1,5 +1,7 @@
 # coding=utf-8
+from __future__ import unicode_literals
 import types
+from .const import DEFAULT_TIMEOUT
 
 
 class Singleton(type):
@@ -41,7 +43,7 @@ class Library(dict):
         Getter for a registered viewlet.
         If not found then scan for decorated viewlets.
         """
-        if not name in self.keys():
+        if name not in self.keys():
             self.autodiscover()
 
         try:
@@ -54,10 +56,11 @@ class Library(dict):
         """
         Adds a registered viewlet to the Library dict
         """
-        if not viewlet.name in self.keys():
+        if viewlet.name not in self.keys():
             self[viewlet.name] = viewlet
 
-    def _decorator(self, name=None, template=None, key=None, timeout=60, cached=True):
+    def _decorator(self, name=None, template=None, key=None, timeout=DEFAULT_TIMEOUT, using=None,
+                   cached=True):
         """
         Handles both decorator pointer and caller (with or without arguments).
         Creates a Viewlet instance to wrap the decorated function with.
@@ -70,7 +73,8 @@ class Library(dict):
                 return viewlet.register(func)
             return declare(name)
         else:
-            viewlet = Viewlet(self, name, template, key, timeout, cached)
+            viewlet = Viewlet(self, name=name, template=template, key=key, timeout=timeout, using=using,
+                              cached=cached)
             return viewlet.register
 
 
