@@ -1,3 +1,6 @@
+# coding=utf-8
+from __future__ import unicode_literals
+import six
 from viewlet.conf import settings
 
 
@@ -20,4 +23,8 @@ def mark_safe(value):
 
 
 def querydict_to_kwargs(querydict):
-    return dict((k.encode('utf-8'), ','.join(querydict.getlist(k))) for k in querydict.keys())
+    if six.PY3:
+        make_key = lambda k: k
+    else:
+        make_key = lambda k: k.encode('utf-8')
+    return dict((make_key(k), ','.join(querydict.getlist(k))) for k in querydict)
