@@ -1,3 +1,5 @@
+# coding=utf-8
+from __future__ import unicode_literals
 from django.http import HttpResponse
 from django.template.context import RequestContext
 import viewlet
